@@ -55,6 +55,21 @@ macro_rules! dec_dualfmt {
     };
 }
 
+macro_rules! size_dualfmt {
+    ($id:expr) => {
+        if ($id >= 1024) {
+            format!(
+                "<span class='number' title='{:#x}'>{} ({})</span>",
+                $id,
+                $id,
+                crate::utils::human_format_bytes($id as u64)
+            )
+        } else {
+            format!("<span class='number' title='{:#x}'>{}</span>", $id, $id)
+        }
+    };
+}
+
 macro_rules! wrow {
     ($dst:expr, $indent_level:expr, $lhs:expr, $rhs:expr) => {
         wnonl!($dst, $indent_level, "<tr> ");
@@ -173,58 +188,52 @@ fn generate_right_menu(o: &mut String) {
     w!(o, 3, "</div>");
 }
 
-fn generate_phdr_info_table(o: &mut String, phdr: &ParsedPhdr, idx: usize) {
-    let items = [
-        ("Type", &ptype_to_string(phdr.ptype)),
-        ("Flags", &phdr.flags),
-        ("Offset in file", &hex_dualfmt!(phdr.file_offset)),
-        ("Size in file", &dec_dualfmt!(phdr.file_size)),
-        ("Vaddr in memory", &hex_dualfmt!(phdr.vaddr)),
-        ("Size in memory", &hex_dualfmt!(phdr.memsz)),
-        ("Alignment", &hex_dualfmt!(phdr.alignment)),
-    ];
-
-    w!(o, 5, "<table class='conceal valign_top' id='info_phdr{}'>", idx);
-
-    for (desc, value) in items.iter() {
-        wrow!(o, 6, desc, value);
-    }
-
-    w!(o, 5, "</table>");
-}
-
 fn generate_phdr_info_tables(o: &mut String, elf: &ParsedElf) {
     for (idx, phdr) in elf.phdrs.iter().enumerate() {
-        generate_phdr_info_table(o, &phdr, idx);
+        let items = [
+            ("Type", &ptype_to_string(phdr.ptype)),
+            ("Flags", &phdr.flags),
+            ("Offset in file", &hex_dualfmt!(phdr.file_offset)),
+            ("Size in file", &size_dualfmt!(phdr.file_size)),
+            ("Vaddr in memory", &hex_dualfmt!(phdr.vaddr)),
+            ("Size in memory", &size_dualfmt!(phdr.memsz)),
+            ("Alignment", &hex_dualfmt!(phdr.alignment)),
+        ];
+
+        w!(o, 5, "<table class='conceal itable' id='info_phdr{}'>", idx);
+        w!(o, 5, "<th colspan='2' class='phdr_itable'></th>");
+
+        for (desc, value) in items.iter() {
+            wrow!(o, 6, desc, value);
+        }
+
+        w!(o, 5, "</table>");
     }
 }
 
-fn generate_shdr_info_table(o: &mut String, elf: &ParsedElf, shdr: &ParsedShdr, idx: usize) {
-    let items = [
-        ("Name", elf.shnstrtab.get(shdr.name)),
-        ("Type", &shtype_to_string(shdr.shtype)),
-        ("Flags", &shflags_to_string(shdr.flags)),
-        ("Vaddr in memory", &hex_dualfmt!(shdr.addr)),
-        ("Offset in file", &hex_dualfmt!(shdr.file_offset)),
-        ("Size in file", &dec_dualfmt!(shdr.size)),
-        ("Linked section", &format!("{}", shdr.link)),
-        ("Extra info", &dec_dualfmt!(shdr.link)),
-        ("Alignment", &hex_dualfmt!(shdr.addralign)),
-        ("Size of entries", &dec_dualfmt!(shdr.entsize)),
-    ];
-
-    w!(o, 5, "<table class='conceal valign_top' id='info_shdr{}'>", idx);
-
-    for (desc, value) in items.iter() {
-        wrow!(o, 6, desc, value);
-    }
-
-    w!(o, 5, "</table>");
-}
-
 fn generate_shdr_info_tables(o: &mut String, elf: &ParsedElf) {
     for (idx, shdr) in elf.shdrs.iter().enumerate() {
-        generate_shdr_info_table(o, elf, &shdr, idx);
+        let items = [
+            ("Name", elf.shnstrtab.get(shdr.name)),
+            ("Type", &shtype_to_string(shdr.shtype)),
+            ("Flags", &shflags_to_string(shdr.flags)),
+            ("Vaddr in memory", &hex_dualfmt!(shdr.addr)),
+            ("Offset in file", &hex_dualfmt!(shdr.file_offset)),
+            ("Size in file", &size_dualfmt!(shdr.size)),
+            ("Linked section", &format!("{}", shdr.link)),
+            ("Extra info", &dec_dualfmt!(shdr.link)),
+            ("Alignment", &hex_dualfmt!(shdr.addralign)),
+            ("Size of entries", &size_dualfmt!(shdr.entsize)),
+        ];
+
+        w!(o, 5, "<table class='conceal itable' id='info_shdr{}'>", idx);
+        w!(o, 5, "<th colspan='2' class='shdr_itable'></th>");
+
+        for (desc, value) in items.iter() {
+            wrow!(o, 6, desc, value);
+        }
+
+        w!(o, 5, "</table>");
     }
 }
 
@@ -354,10 +363,12 @@ fn has_section_detail(ptype: u32) -> bool {
 
 fn generate_segment_info_tables(o: &mut String, elf: &ParsedElf) {
     for (idx, phdr) in elf.phdrs.iter().enumerate() {
-        w!(o, 5, "<table class='conceal valign_top' id='info_segment{}'>", idx);
-        wrow!(o, 6, "Segment type", &ptype_to_string(phdr.ptype));
-        wrow!(o, 6, "Size in file", dec_dualfmt!(phdr.file_size));
-        wrow!(o, 6, "Size in memory", dec_dualfmt!(phdr.memsz));
+        w!(o, 5, "<table class='conceal itable' id='info_segment{}'>", idx);
+        w!(o, 5, "<th colspan='2' class='segment_itable'></th>");
+
+        wrow!(o, 6, "Type", &ptype_to_string(phdr.ptype));
+        wrow!(o, 6, "Size in file", size_dualfmt!(phdr.file_size));
+        wrow!(o, 6, "Size in memory", size_dualfmt!(phdr.memsz));
 
         if has_segment_detail(phdr.ptype) {
             w!(o, 6, "<tr><td><br></td></tr>");
@@ -370,9 +381,11 @@ fn generate_segment_info_tables(o: &mut String, elf: &ParsedElf) {
 
 fn generate_section_info_tables(o: &mut String, elf: &ParsedElf) {
     for (idx, shdr) in elf.shdrs.iter().enumerate() {
-        w!(o, 5, "<table class='conceal valign_top' id='info_section{}'>", idx);
-        wrow!(o, 6, "Section type", &shtype_to_string(shdr.shtype));
-        wrow!(o, 6, "Size", dec_dualfmt!(shdr.size));
+        w!(o, 5, "<table class='conceal itable' id='info_section{}'>", idx);
+        w!(o, 5, "<th colspan='2' class='section_itable'></th>");
+
+        wrow!(o, 6, "Type", &shtype_to_string(shdr.shtype));
+        wrow!(o, 6, "Size", size_dualfmt!(shdr.size));
 
         if has_section_detail(shdr.shtype) {
             w!(o, 6, "<tr><td><br></td></tr>");
@@ -383,19 +396,19 @@ fn generate_section_info_tables(o: &mut String, elf: &ParsedElf) {
     }
 }
 
-fn generate_sticky_info_table(o: &mut String, elf: &ParsedElf) {
+fn generate_sticky_info_tables(o: &mut String, elf: &ParsedElf) {
     w!(o, 2, "<table id='sticky_table' cellspacing='0'>");
     w!(o, 3, "<tr>");
 
     w!(o, 4, "<td id='desc'></td>");
 
-    w!(o, 4, "<td id='struct_infotables'>");
+    w!(o, 4, "<td class='infotables'>");
     generate_phdr_info_tables(o, elf);
 
     generate_shdr_info_tables(o, elf);
     w!(o, 4, "</td>");
 
-    w!(o, 4, "<td id='data_infotables'>");
+    w!(o, 4, "<td class='infotables'>");
     generate_segment_info_tables(o, elf);
 
     generate_section_info_tables(o, elf);
@@ -483,15 +496,6 @@ fn add_arrows_script(o: &mut String, elf: &ParsedElf) {
     w!(o, 2, "</script>");
 }
 
-#[allow(dead_code)]
-fn add_collapsible_script(o: &mut String) {
-    w!(o, 2, "<script type='text/javascript'>");
-
-    wnonl!(o, 0, "{}", include_str!("js/collapse.js").indent_lines(3));
-
-    w!(o, 2, "</script>");
-}
-
 fn add_settings_script(o: &mut String) {
     w!(o, 2, "<script type='text/javascript'>");
 
@@ -507,9 +511,6 @@ fn add_scripts(o: &mut String, elf: &ParsedElf) {
 
     add_conceal_script(o);
 
-    // disabled while working on section headers because it doesn't work for nested elements
-    // add_collapsible_script(o);
-
     add_offsets_script(o, elf);
 
     add_arrows_script(o, elf);
@@ -669,11 +670,14 @@ fn generate_body(o: &mut String, elf: &ParsedElf) {
 
     generate_file_info_table(o, elf);
 
-    w!(o, 2, "<div id='offsets'>");
+    wnonl!(o, 2, "<div id='offsets'>");
     for off in (0..elf.contents.len()).step_by(DEFAULT_COLUMNS) {
-        w!(o, 3, "{:x}</br>", off);
+        wnonl!(o, 0, "{:x}", off);
+        if off != (elf.contents.len() / DEFAULT_COLUMNS) * DEFAULT_COLUMNS {
+            w!(o, 0, "");
+        }
     }
-    w!(o, 2, "</div>");
+    w!(o, 0, "</div>");
 
     wnonl!(o, 2, "<div id='bytes'>");
     wnonl!(o, 0, "{}", generate_file_dump(elf));
@@ -681,9 +685,9 @@ fn generate_body(o: &mut String, elf: &ParsedElf) {
 
     wnonl!(o, 2, "<div id='ascii'>");
     generate_ascii_dump(o, elf);
-    w!(o, 2, "</div>");
+    w!(o, 0, "</div>");
 
-    generate_sticky_info_table(o, elf);
+    generate_sticky_info_tables(o, elf);
 
     add_scripts(o, elf);
 
